@@ -11,7 +11,7 @@ use overload
     '""' => \&as_string,
     fallback => 1;
 
-$VERSION = '0.75';
+$VERSION = '0.8';
 
 1;
 
@@ -63,11 +63,11 @@ sub _add_frames
 	next if $i_pack{ $c[0] };
 	next if ( grep { $c[0]->isa($_) } keys %i_class );
 
-	# eval and is_require are only returned when applicable.
+	# eval and is_require are only returned when applicable under 5.00503.
 	push @c, (undef, undef) if scalar @c == 6;
 
 	my @a = @DB::args;
-	push @{ $self->{frames} }, Devel::StackTraceFrame->new(@c, \@a);
+	push @{ $self->{frames} }, Devel::StackTraceFrame->new(@c, @a);
     }
 }
 
@@ -158,7 +158,7 @@ package Devel::StackTraceFrame;
 use strict;
 use vars qw($VERSION);
 
-use fields qw( package filename line subroutine hasargs wantarray evaltext is_require args );
+use fields qw( package filename line subroutine hasargs wantarray evaltext is_require hints bitmask args );
 
 $VERSION = '0.5';
 
@@ -186,7 +186,11 @@ sub new
 	$self = bless [ \%{"${class}::FIELDS"} ], $class;
     }
 
-    @{ $self }{ qw( package filename line subroutine hasargs wantarray evaltext is_require args ) } = @_;
+    my @fields = ( qw( package filename line subroutine hasargs wantarray evaltext is_require ) );
+    push @fields, ( qw( hints bitmask ) ) if $] >= 5.006;
+    @{ $self }{ @fields } = splice @_, 0, scalar @fields;
+
+    $self->{args} = \@_;
 
     return $self;
 }
@@ -350,9 +354,10 @@ the stack.
 Any frames where the package is a subclass of one of these packages
 (or is the same package) will not be on the stack.
 
-Devel::StackTrace internally adds itself to the 'ignore_package' parameter,
-meaning that the Devel::StackTrace package is B<ALWAYS> ignored.  However, if
-you create a subclass of Devel::StackTrace it will not be ignored.
+Devel::StackTrace internally adds itself to the 'ignore_package'
+parameter, meaning that the Devel::StackTrace package is B<ALWAYS>
+ignored.  However, if you create a subclass of Devel::StackTrace it
+will not be ignored.
 
 =item * next_frame
 
@@ -424,6 +429,12 @@ Returns undef if the frame was not part of an eval.
 
 Returns undef if the frame was not part of a require.
 
+=head2 Perl 5.6.0 and greater _ONLY_
+
+=item * hints
+
+=item * bitmask
+
 =item * args
 
 Returns the arguments passed to the frame.  Note that any arguments
